@@ -3,12 +3,12 @@ deleted_ids = new Set()
 
 /*更新deleted_ids，并事实上隐藏他们*/
 function hide_checked_rows() {
-	var checkStatus = table.checkStatus('the_table');
+	var checkStatus = table.checkStatus("the_table");
 	var checkData = checkStatus.data
 
 	for(var i = 0;i < checkData.length;i++)
 	{
-		deleted_ids.add(checkData[i].id)
+		deleted_ids.add( parseInt(checkData[i].id).toString())
 	}
 
 
@@ -36,17 +36,19 @@ function hide_checked_rows() {
 			del_idxs.push(r.getAttribute("data-index"))
 		}
 	}
-	
 
 	var trs = document.getElementsByTagName("tr")
 	for(var i = 0;i < trs.length;i++)
 	{
 		if(del_idxs.indexOf(trs[i].getAttribute("data-index")) >= 0)
+		{
+			trs[i]["hide_by_delete"] = true
 			trs[i].hidden = true
+		}
 	}
 
-	//console.log("ids" , deleted_ids)
-	//console.log("idxs" , del_idxs)
+	console.log("ids" , deleted_ids)
+	console.log("idxs" , del_idxs)
 }
 
 /*返回隐藏的列*/
@@ -62,3 +64,19 @@ function get_hide_headers() {
 	}
 	return hide_list
 }
+
+/*返回显示的列的顺序*/
+function get_show_headers() {
+	var headers = document.getElementsByClassName("layui-table-header")[0]
+	headers = headers.children[0].children[0].children[0].children
+
+	var show_list = []
+	for(var i = 0;i < headers.length;i++)
+	{
+		if(headers[i].tagName == "TH") //表头
+		{
+			show_list.push(headers[i].innerText)
+		}
+	}
+	return show_list
+}
